DataType

Enum DataType 

pub enum DataType {
Show 15 variants Bool, U32, U64, U128, U160, U192, I128, Bfe, Xfe, Digest, List(Box<DataType>), Array(Box<ArrayType>), Tuple(Vec<DataType>), VoidPointer, StructRef(StructType),
}
A type hint for developers of Triton Assembly.

Note that no type checking is performed.

Variants



Bool



U32



U64



U128



U160



U192



I128



Bfe



Xfe



Digest



List(Box<DataType>)



Array(Box<ArrayType>)



Tuple(Vec<DataType>)



VoidPointer



StructRef(StructType)

Implementations

Source

impl DataType

pub fn label_friendly_name(&self) -> String

A string which can be used as part of function labels in Triton-VM.

pub fn stack_size(&self) -> usize

The size that the data type takes up on stack

pub fn read_value_from_memory_leave_pointer(&self) -> Vec<LabelledInstruction>

The code to read a value of this type from memory. Leaves mutated point on top of stack.

BEFORE: _ (*address + self.stack_size() - 1)
AFTER:  _ [value] (*address - 1)
pub fn read_value_from_memory_pop_pointer(&self) -> Vec<LabelledInstruction>

The code to read a value of this type from memory. Pops pointer from stack.

BEFORE: _ (*address + self.stack_size() - 1)
AFTER:  _ [value]
pub fn write_value_to_memory_leave_pointer(&self) -> Vec<LabelledInstruction>

The code to write a value of this type to memory

BEFORE: _ [value] *address
AFTER:  _ (*address + self.stack_size())
pub fn write_value_to_memory_pop_pointer(&self) -> Vec<LabelledInstruction>

The code to write a value of this type to memory

BEFORE: _ [value] *address
AFTER:  _
pub fn read_value_from_input( &self, input_source: InputSource, ) -> Vec<LabelledInstruction>

The code to read a value of this type from the specified input source

BEFORE: _
AFTER:  _ [value]
pub fn write_value_to_stdout(&self) -> Vec<LabelledInstruction>

The code to write a value of this type to standard output

BEFORE: _ [value]
AFTER:  _
pub fn compare_elem_of_stack_size(stack_size: usize) -> Vec<LabelledInstruction>

The code that compares two elements of this stack-size.

BEFORE: _ [self] [other]
AFTER:  _ (self == other)
pub fn compare(&self) -> Vec<LabelledInstruction>

The code that compares two elements of this type.

BEFORE: _ [self] [other]
AFTER:  _ (self == other)
pub fn variant_name(&self) -> String

A string matching how the variant looks in source code.

pub fn random_elements(&self, count: usize) -> Vec<Vec<BFieldElement>>

pub fn seeded_random_element(&self, rng: &mut impl Rng) -> Vec<BFieldElement>