Literal

Enum Literal 

pub enum Literal {
    Bool(bool),
    U32(u32),
    U64(u64),
    U128(u128),
    I128(i128),
    Bfe(BFieldElement),
    Xfe(XFieldElement),
    Digest(Digest),
}

Variants



Bool(bool)



U32(u32)



U64(u64)



U128(u128)



I128(i128)



Bfe(BFieldElement)



Xfe(XFieldElement)



Digest(Digest)

Implementations

Source

impl Literal

pub fn data_type(&self) -> DataType

pub fn as_xfe(&self) -> XFieldElement

Panics

Panics if self is anything but an extension field element.

pub fn push_to_stack_code(&self) -> Vec<LabelledInstruction>

The code to push the literal to the stack.

pub fn pop_from_stack( data_type: DataType, stack: &mut Vec<BFieldElement>, ) -> Self

Panics
  • if the stack is too shallow
  • if the top of the stack does not contain an element of the requested type
  • if the element is incorrectly BFieldCodec encoded