pub struct SplitOff {
pub element_type: DataType,
}Expand description
Mutates an existing vector by reducing its length to at and returns the new vector. Mirrors
the behavior of the Rust method Vec::split_off.
Fields
element_type: DataTypeTrait Implementations
Sourceimpl BasicSnippet for SplitOff
impl BasicSnippet for SplitOff
fn inputs(&self) -> Vec<(DataType, String)>
fn outputs(&self) -> Vec<(DataType, String)>
fn entrypoint(&self) -> String
fn code(&self, library: &mut Library) -> Vec<LabelledInstruction>
fn annotated_code(&self, library: &mut Library) -> Vec<LabelledInstruction>
fn link_for_isolated_run(&self) -> Vec<LabelledInstruction>
Sourcefn init_stack_for_isolated_run(&self) -> Vec<BFieldElement>
fn init_stack_for_isolated_run(&self) -> Vec<BFieldElement>
Intial stack on program start, when the snippet runs in isolation.
fn stack_diff(&self) -> isize
impl Eq for SplitOff
impl StructuralPartialEq for SplitOff