pub enum RustShadowError {
ArithmeticOverflow,
DecodingError,
InvalidProof,
SpongeUninitialized,
StackUnderflow,
U64ToU32Error,
U64ToUsizeError,
UsizeToU32Error,
VmError,
AssertionError(i128),
VectorAssertionError(i128),
Other,
}Expand description
Errors that can occur during the execution of the Rust shadow implementation of a snippet.
Variants
ArithmeticOverflow
DecodingError
InvalidProof
SpongeUninitialized
StackUnderflow
U64ToU32Error
U64ToUsizeError
UsizeToU32Error
VmError
AssertionError(i128)
Mimics a Triton VM AssertionError.
The payload can be used to check error ID equivalence.
VectorAssertionError(i128)
Like AssertionError, but for vector assertions.
Other
An unspecified issue.